@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::PluginBundle::NGLENN;
 # ABSTRACT: Dist::Zilla plugin configuration for me
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 # Dependencies
 use Moose 0.99;
@@ -39,6 +39,7 @@ use Dist::Zilla::Plugin::PromptIfStale 0.011 ();
 use Dist::Zilla::Plugin::Prereqs::AuthorDeps ();
 use Dist::Zilla::Plugin::RewriteVersion ();
 use Dist::Zilla::Plugin::ReadmeFromPod 0.19            (); # for dzil v5
+use Dist::Zilla::Plugin::InstallGuide                  ();
 use Dist::Zilla::Plugin::TaskWeaver 0.101620           ();
 use Dist::Zilla::Plugin::Test::Compile 2.036           (); # various features
 use Dist::Zilla::Plugin::Test::MinimumVersion 2.000003 ();
@@ -256,6 +257,7 @@ sub configure {
 
         # generated distribution files
         'ReadmeFromPod', # in build dir
+        'InstallGuide',   # in build dir
         'TravisCI::StatusBadge', # in readme file
         'License',       # core
 
@@ -450,7 +452,7 @@ __PACKAGE__->meta->make_immutable;
 #
 # This file is part of Dist-Zilla-PluginBundle-NGLENN
 #
-# This software is Copyright (c) 2015 by Nathan Glenn.
+# This software is Copyright (c) 2017 by Nathan Glenn.
 #
 # This is free software, licensed under:
 #
@@ -469,7 +471,7 @@ Dist::Zilla::PluginBundle::NGLENN - Dist::Zilla plugin configuration for me
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -506,6 +508,7 @@ following dist.ini:
   ; generated files
   [License]           ; boilerplate license
   [ReadmeFromPod]     ; from Pod (runs after PodWeaver)
+  [InstallGuide]      ; installation guide
   [TravisYML]         ; Travis-CI configuration
   build_branch = master
   ; t tests
@@ -804,6 +807,10 @@ Nathan Glenn <garfieldnate@gmail.com>
 
 =item *
 
+Nathan Glenn <nathan-gary.glenn@trivago.com>
+
+=item *
+
 Philippe Bruhat (BooK) <book@cpan.org>
 
 =item *
@@ -814,7 +821,7 @@ Sergey Romanov <complefor@rambler.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Nathan Glenn.
+This software is Copyright (c) 2017 by Nathan Glenn.
 
 This is free software, licensed under:
 
